@@ -13,8 +13,7 @@ test_that("flux calculation is correct", {
     f_slope,
     datetime,
     temp_air,
-    chamber_volume = 24.5,
-    tube_volume = 0.075,
+    setup_volume = 24.575,
     atm_pressure = 1,
     plot_area = 0.0625,
     conc_unit = "ppm",
@@ -49,13 +48,14 @@ test_that("averaging works", {
     conc_unit = "ppm",
     flux_unit = "mmol",
     cols_ave = c("PAR", "temp_soil"),
-    chamber_volume = 24.5,
-    tube_volume = 0.075,
+    setup_volume = 24.575,
     atm_pressure = 1,
     plot_area = 0.0625,
     cut = FALSE
   ) |>
-    dplyr::select(f_fluxid, f_temp_air_ave, datetime, f_flux, PAR, temp_soil)
+    dplyr::select(
+      f_fluxid, f_temp_air_ave, datetime, f_flux, PAR_ave, temp_soil_ave
+    )
 
 
   expect_snapshot(output)
@@ -80,8 +80,7 @@ test_that("keeping works", {
     conc_unit = "ppm",
     flux_unit = "mmol",
     cols_keep = c("turfID", "type", "f_start"),
-    chamber_volume = 24.5,
-    tube_volume = 0.075,
+    setup_volume = 24.575,
     atm_pressure = 1,
     plot_area = 0.0625,
     cut = FALSE
@@ -109,13 +108,82 @@ test_that("keeping and averaging work together", {
     flux_unit = "mmol",
     cols_keep = c("turfID", "type", "f_start"),
     cols_ave = c("PAR", "temp_soil"),
-    chamber_volume = 24.5,
-    tube_volume = 0.075,
+    setup_volume = 24.575,
     atm_pressure = 1,
     plot_area = 0.0625,
     cut = FALSE
   ) |>
-    dplyr::select(f_fluxid, f_flux, turfID, type, f_start, PAR, temp_soil))
+    dplyr::select(
+      f_fluxid, f_flux, turfID, type, f_start, PAR_ave, temp_soil_ave
+    ))
+})
+
+test_that("nesting works", {
+  slopes0 <- suppressWarnings(flux_fitting(
+    co2_conc,
+    conc,
+    datetime,
+    fit_type = "linear"
+  )) |>
+    flux_quality(
+      conc
+    )
+
+  output <- flux_calc(
+    slopes0,
+    f_slope,
+    datetime,
+    temp_air,
+    conc_unit = "ppm",
+    flux_unit = "mmol",
+    cols_ave = c("PAR", "temp_soil"),
+    cols_nest = c("conc", "PAR"),
+    setup_volume = 24.575,
+    atm_pressure = 1,
+    plot_area = 0.0625,
+    cut = FALSE
+  ) |>
+    dplyr::select(
+      f_fluxid, datetime, f_flux, PAR_ave, temp_soil_ave, nested_variables
+    ) |>
+    tidyr:: unnest(cols = nested_variables)
+
+
+  expect_snapshot(output)
+})
+
+test_that("nesting all works", {
+  slopes0 <- suppressWarnings(flux_fitting(
+    co2_conc,
+    conc,
+    datetime,
+    fit_type = "linear"
+  )) |>
+    flux_quality(
+      conc
+    )
+
+  output <- flux_calc(
+    slopes0,
+    f_slope,
+    datetime,
+    temp_air,
+    conc_unit = "ppm",
+    flux_unit = "mmol",
+    cols_ave = c("PAR", "temp_soil"),
+    cols_nest = "all",
+    setup_volume = 24.575,
+    atm_pressure = 1,
+    plot_area = 0.0625,
+    cut = FALSE
+  ) |>
+    dplyr::select(
+      f_fluxid, datetime, f_flux, PAR_ave, temp_soil_ave, nested_variables
+    ) |>
+    tidyr:: unnest(cols = nested_variables, names_sep = "_")
+
+
+  expect_snapshot(output)
 })
 
 test_that("fahrenheit conversion works", {
@@ -127,13 +195,12 @@ test_that("fahrenheit conversion works", {
     conc_unit = "ppm",
     flux_unit = "mmol",
     temp_air_unit = "fahrenheit",
-    chamber_volume = 24.5,
-    tube_volume = 0.075,
+    setup_volume = 24.575,
     atm_pressure = 1,
     plot_area = 0.0625,
     cut = FALSE
   ) |>
-    dplyr::select(f_fluxid, f_temp_air_ave, datetime, f_flux, f_volume_setup))
+    dplyr::select(f_fluxid, f_temp_air_ave, datetime, f_flux))
 })
 
 test_that("kelvin conversion works", {
@@ -145,13 +212,12 @@ test_that("kelvin conversion works", {
     conc_unit = "ppm",
     flux_unit = "mmol",
     temp_air_unit = "kelvin",
-    chamber_volume = 24.5,
-    tube_volume = 0.075,
+    setup_volume = 24.575,
     atm_pressure = 1,
     plot_area = 0.0625,
     cut = FALSE
   ) |>
-    dplyr::select(f_fluxid, f_temp_air_ave, datetime, f_flux, f_volume_setup))
+    dplyr::select(f_fluxid, f_temp_air_ave, datetime, f_flux))
 })
 
 
@@ -178,8 +244,7 @@ test_that("error on air temp units", {
       conc_unit = "ppm",
       flux_unit = "mmol",
       temp_air_unit = "melvin",
-      chamber_volume = 24.5,
-      tube_volume = 0.075,
+      setup_volume = 24.575,
       atm_pressure = 1,
       plot_area = 0.0625,
       cut = FALSE
@@ -218,8 +283,7 @@ test_that("error that slope column is missing", {
       temp_air,
       conc_unit = "ppm",
       flux_unit = "mmol",
-      chamber_volume = 24.5,
-      tube_volume = 0.075,
+      setup_volume = 24.575,
       atm_pressure = 1,
       plot_area = 0.0625,
       cut = FALSE
@@ -247,8 +311,7 @@ test_that("error slope_col cannot be found in slopes_df", {
       temp_air,
       conc_unit = "ppm",
       flux_unit = "mmol",
-      chamber_volume = 24.5,
-      tube_volume = 0.075,
+      setup_volume = 24.575,
       atm_pressure = 1,
       plot_area = 0.0625,
       cut = FALSE
@@ -278,8 +341,7 @@ test_that("error some cols_keep do not exist", {
       conc_unit = "ppm",
       flux_unit = "mmol",
       cols_keep = c("PAR", "site"),
-      chamber_volume = 24.5,
-      tube_volume = 0.075,
+      setup_volume = 24.575,
       atm_pressure = 1,
       plot_area = 0.0625,
       cut = FALSE
@@ -311,12 +373,11 @@ test_that("calculating fluxes on dataset with cuts", {
       conc_unit = "ppm",
       flux_unit = "mmol",
       keep_arg = "keep",
-      chamber_volume = 24.5,
-      tube_volume = 0.075,
+      setup_volume = 24.575,
       atm_pressure = 1,
       plot_area = 0.0625
     ) |>
-      dplyr::select(f_fluxid, f_temp_air_ave, datetime, f_flux, f_volume_setup)
+      dplyr::select(f_fluxid, f_temp_air_ave, datetime, f_flux)
   )
 })
 
@@ -339,7 +400,8 @@ test_that("volume can be a variable instead of a constant", {
         f_fluxid == 4 ~ 24,
         f_fluxid == 5 ~ 4,
         f_fluxid == 6 ~ 35
-      )
+      ),
+      volume = volume + 0.075 # adding the tube volume since v1.2.2
     )
 
   expect_snapshot(
@@ -348,14 +410,13 @@ test_that("volume can be a variable instead of a constant", {
       f_slope,
       datetime,
       temp_air,
-      volume,
+      setup_volume = volume,
       conc_unit = "ppm",
       flux_unit = "mmol",
-      tube_volume = 0.075,
       atm_pressure = 1,
       plot_area = 0.0625
     ) |>
-      dplyr::select(f_fluxid, f_temp_air_ave, datetime, f_flux, f_volume_setup)
+      dplyr::select(f_fluxid, f_temp_air_ave, datetime, f_flux)
   )
 })
 
@@ -366,8 +427,6 @@ test_that("Fluxible workflow works from start to finish", {
     record_short,
     datetime,
     start,
-    conc,
-    startcrop = 10,
     measurement_length = 180
   )
   slopes_test <- suppressWarnings(flux_fitting(
@@ -375,6 +434,7 @@ test_that("Fluxible workflow works from start to finish", {
     conc,
     datetime,
     start,
+    start_cut = 10,
     fit_type = "exp_zhao18"
   ))
   slopes_flag_test <- flux_quality(
@@ -388,8 +448,7 @@ test_that("Fluxible workflow works from start to finish", {
     temp_air,
     conc_unit = "ppm",
     flux_unit = "mmol",
-    chamber_volume = 24.5,
-    tube_volume = 0.075,
+    setup_volume = 24.575,
     atm_pressure = 1,
     plot_area = 0.0625
   )
@@ -405,8 +464,6 @@ test_that("Stupeflux returns the same as step by step workflow", {
     record_short,
     datetime,
     start,
-    conc,
-    startcrop = 10,
     measurement_length = 180
   )
   slopes_test <- suppressWarnings(flux_fitting(
@@ -414,6 +471,7 @@ test_that("Stupeflux returns the same as step by step workflow", {
     conc,
     datetime,
     f_start,
+    start_cut = 10,
     fit_type = "exp_zhao18"
   ))
   slopes_flag_test <- flux_quality(
@@ -427,8 +485,7 @@ test_that("Stupeflux returns the same as step by step workflow", {
     temp_air,
     conc_unit = "ppm",
     flux_unit = "mmol",
-    chamber_volume = 24.5,
-    tube_volume = 0.075,
+    setup_volume = 24.575,
     atm_pressure = 1,
     plot_area = 0.0625
   )
@@ -440,14 +497,13 @@ test_that("Stupeflux returns the same as step by step workflow", {
       f_datetime = datetime,
       start_col = start,
       f_conc = conc,
-      startcrop = 10,
+      start_cut = 10,
       measurement_length = 180,
       fit_type = "exp_zhao18",
       temp_air_col = temp_air,
       conc_unit = "ppm",
       flux_unit = "mmol",
-      chamber_volume = 24.5,
-      tube_volume = 0.075,
+      setup_volume = 24.575,
       atm_pressure = 1,
       plot_area = 0.0625
     ),
@@ -463,14 +519,13 @@ test_that("Stupeflux works with slope_correction = FALSE", {
       f_datetime = datetime,
       start_col = start,
       f_conc = conc,
-      startcrop = 10,
+      start_cut = 10,
       measurement_length = 180,
       fit_type = "exp_zhao18",
       temp_air_col = temp_air,
       conc_unit = "ppm",
       flux_unit = "mmol",
-      chamber_volume = 24.5,
-      tube_volume = 0.075,
+      setup_volume = 24.575,
       atm_pressure = 1,
       plot_area = 0.0625,
       slope_correction = FALSE
@@ -484,8 +539,6 @@ test_that("Fluxible workflow works with kappamax", {
     record_short,
     datetime,
     start,
-    conc,
-    startcrop = 10,
     measurement_length = 220
   )
   slopes_test <- suppressWarnings(flux_fitting(
@@ -493,6 +546,7 @@ test_that("Fluxible workflow works with kappamax", {
     conc,
     datetime,
     start,
+    start_cut = 10,
     end_cut = 30,
     fit_type = "exp_hm"
   ))
@@ -510,8 +564,7 @@ test_that("Fluxible workflow works with kappamax", {
     temp_air,
     conc_unit = "ppm",
     flux_unit = "mmol",
-    chamber_volume = 24.5,
-    tube_volume = 0.075,
+    setup_volume = 24.575,
     atm_pressure = 1,
     plot_area = 0.0625
   ) |>
@@ -528,10 +581,7 @@ test_that("Working with two gases", {
     twogases_record,
     datetime,
     start,
-    co2_conc,
-    startcrop = 10,
     measurement_length = 180,
-    ratio_threshold = 0.5,
     time_diff = 0
   )
 
@@ -539,14 +589,16 @@ test_that("Working with two gases", {
     conc_twogases,
     co2_conc,
     datetime,
-    fit_type = "exponential"
+    fit_type = "exponential",
+    start_cut = 10
   )
 
   slopes_twogases_ch4 <- flux_fitting(
     conc_twogases,
     ch4_conc,
     datetime,
-    fit_type = "exponential"
+    fit_type = "exponential",
+    start_cut = 10
   )
 
   flag_twogases_co2 <- flux_quality(
@@ -568,8 +620,7 @@ test_that("Working with two gases", {
     temp_air,
     conc_unit = "ppm",
     flux_unit = "mmol",
-    chamber_volume = 6.3,
-    tube_volume = 0.01,
+    setup_volume = 6.31,
     atm_pressure = 1,
     plot_area = 0.31,
     cols_keep = "f_quality_flag" # to use the flags of CO2 to discard CH4 fluxes
@@ -586,8 +637,7 @@ test_that("Working with two gases", {
     temp_air,
     conc_unit = "ppb", # ch4 is measured in ppb
     flux_unit = "micromol", # we want a flux in umol/m2/h
-    chamber_volume = 6.3,
-    tube_volume = 0.01,
+    setup_volume = 6.31,
     atm_pressure = 1,
     plot_area = 0.31
   ) |>
@@ -603,8 +653,7 @@ test_that("Working with two gases", {
       "f_fluxid",
       "f_temp_air_ave",
       "datetime",
-      "f_model",
-      "f_volume_setup"
+      "f_model"
     )
   ) |>
     mutate( # we discard the CH4 fluxes based on CO2 fluxes quality flags
@@ -639,13 +688,45 @@ test_that("sum and median works", {
     flux_unit = "mmol",
     cols_sum = "PAR",
     cols_med = "temp_soil",
-    chamber_volume = 24.5,
-    tube_volume = 0.075,
+    setup_volume = 24.575,
     atm_pressure = 1,
     plot_area = 0.0625,
     cut = FALSE
   ) |>
-    dplyr::select(f_fluxid, f_temp_air_ave, datetime, f_flux, PAR, temp_soil)
+    dplyr::select(
+      f_fluxid, f_temp_air_ave, datetime, f_flux, PAR_sum, temp_soil_med
+    )
+
+
+  expect_snapshot(output)
+})
+
+test_that("sum and average works on same variable", {
+  slopes0 <- suppressWarnings(flux_fitting(
+    co2_conc,
+    conc,
+    datetime,
+    fit_type = "exp_zhao18"
+  )) |>
+    flux_quality(
+      conc
+    )
+
+  output <- flux_calc(
+    slopes0,
+    f_slope,
+    datetime,
+    temp_air,
+    conc_unit = "ppm",
+    flux_unit = "mmol",
+    cols_sum = "PAR",
+    cols_ave = c("temp_soil", "PAR"),
+    setup_volume = 24.575,
+    atm_pressure = 1,
+    plot_area = 0.0625,
+    cut = FALSE
+  ) |>
+    dplyr::select(f_fluxid, datetime, f_flux, PAR_sum, temp_soil_ave, PAR_ave)
 
 
   expect_snapshot(output)
